from websockethost.basicCGIserver import startCGIserver
from websockethost.basicserverhttp import start_server_http
from websockethost.socketServerClient.server import start_socket_server
from websockethost.socketServerClient.client import start_client_socket